==> 0.0.32.tar.gz: lib/src/widgets/upload_photo_widget.dart <==
import 'package:fluentui_icons/fluentui_icons.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';

import '../../ametory_ui.dart';

class UploadPhotoWidget extends StatelessWidget {
  final Function(String, String) onUploaded;
  final String url;
  final Color? backgroundColor;
  final BoxShape shape;
  final Function(bool)? onLoading;
  final Function()? onTap;
  final Function(XFile?)? onPickImage;

  const UploadPhotoWidget(
      {Key? key,
      required this.onUploaded,
      required this.url,
      this.onLoading,
      this.shape = BoxShape.circle,
      this.backgroundColor,
      this.onTap,
      this.onPickImage})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: url.isNotEmpty
          ? GestureDetector(
              onTap: onTap ??
                  () async {
                    if (onPickImage != null) {
                      final ImagePicker picker = ImagePicker();
                      final XFile? image =
                          await picker.pickImage(source: ImageSource.gallery);
                      onPickImage!(image);
                    }
                  },
              child: (shape == BoxShape.circle)
                  ? SizedBox(
                      width: 100,
                      height: 100,
                      child: CircleAvatar(
                          backgroundColor: backgroundColor,
                          backgroundImage: NetworkImage(
                            url,
                          )))
                  : ClipRRect(
                      borderRadius: BorderRadius.circular(20),
                      child: SizedBox(
                        width: double.infinity,
                        height: 200,
                        child: Image.network(url, fit: BoxFit.cover),
                      ),
                    ),
            )
          : GestureDetector(
              onTap: onTap ??
                  () async {
                    if (onPickImage != null) {
                      final ImagePicker picker = ImagePicker();
                      final XFile? image =
                          await picker.pickImage(source: ImageSource.gallery);
                      onPickImage!(image);
                    }
                  },
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Container(
                    width: shape == BoxShape.circle ? 100 : null,
                    height: shape == BoxShape.circle ? 100 : 200,
                    decoration: BoxDecoration(
                        color: backgroundColor ?? Colors.white,
                        borderRadius: BorderRadius.circular(
                            shape == BoxShape.circle ? 50 : 20)),
                    child: const Center(
                      child: Icon(
                        FluentSystemIcons.ic_fluent_camera_regular,
                        color: Colors.grey,
                      ),
                    ),
                  ),
                  vspace(10),
                  Text(
                    'Tambahkan Photo',
                    style: MyTypo.smallText,
                  )
                ],
              ),
            ),
    );
  }
}

==> 0.0.50.tar.gz: lib/src/widgets/upload_photo_widget.dart <==
import 'package:fluentui_icons/fluentui_icons.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';

import '../../ametory_ui.dart';

class UploadPhotoWidget extends StatelessWidget {
  final Function(String, String)? onUploaded;
  final String url;
  final Color? backgroundColor;
  final BoxShape shape;
  final Function(bool)? onLoading;
  final Function()? onTap;
  final Function(XFile?)? onPickImage;

  const UploadPhotoWidget(
      {Key? key, this.onUploaded, required this.url, this.onLoading, this.shape = BoxShape.circle, this.backgroundColor, this.onTap, this.onPickImage})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: url.isNotEmpty
          ? GestureDetector(
              onTap: onTap ??
                  () async {
                    if (onPickImage != null) {
                      final ImagePicker picker = ImagePicker();
                      final XFile? image = await picker.pickImage(source: ImageSource.gallery);
                      onPickImage!(image);
                    }
                  },
              child: (shape == BoxShape.circle)
                  ? SizedBox(
                      width: 100,
                      height: 100,
                      child: CircleAvatar(
                          backgroundColor: backgroundColor,
                          backgroundImage: NetworkImage(
                            url,
                          )))
                  : ClipRRect(
                      borderRadius: BorderRadius.circular(20),
                      child: SizedBox(
                        width: double.infinity,
                        height: 200,
                        child: Image.network(url, fit: BoxFit.cover),
                      ),
                    ),
            )
          : GestureDetector(
              onTap: onTap ??
                  () async {
                    if (onPickImage != null) {
                      final ImagePicker picker = ImagePicker();
                      final XFile? image = await picker.pickImage(source: ImageSource.gallery);
                      onPickImage!(image);
                    }
                  },
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Container(
                    width: shape == BoxShape.circle ? 100 : null,
                    height: shape == BoxShape.circle ? 100 : 200,
                    decoration: BoxDecoration(color: backgroundColor ?? Colors.white, borderRadius: BorderRadius.circular(shape == BoxShape.circle ? 50 : 20)),
                    child: const Center(
                      child: Icon(
                        FluentSystemIcons.ic_fluent_camera_regular,
                        color: Colors.grey,
                      ),
                    ),
                  ),
                  vspace(10),
                  Text(
                    'Tambahkan Photo',
                    style: MyTypo.smallText,
                  )
                ],
              ),
            ),
    );
  }
}
